@@ -7,7 +7,7 @@ use super::domain::Domain;
 /// [`Function`](super::function::Function).
 pub trait Problem {
     /// Type of the scalar, usually f32 or f64.
-    type Scalar: RealField;
+    type Scalar: RealField + Copy;
 
     /// Dimension of the system. Can be fixed
     /// ([`Const`](nalgebra::base::dimension::Const)) or dynamic
@@ -25,9 +25,9 @@ pub trait Problem {
     }
 }
 
-/// Error encountered while applying variables to the function.
+/// Error encountered while applying variables to the problem.
 #[derive(Debug, Error)]
-pub enum Error {
+pub enum ProblemError {
     /// The number of variables does not match the dimensionality
     /// ([`Problem::dim`]) of the problem.
     #[error("invalid dimensionality")]
