@@ -33,13 +33,14 @@ use nalgebra::{
     allocator::{Allocator, Reallocator},
     convert,
     storage::StorageMut,
-    ComplexField, DefaultAllocator, Dim, DimMin, DimName, OMatrix, OVector, RealField, Vector, U1,
+    ComplexField, DefaultAllocator, Dim, DimMin, DimName, IsContiguous, OMatrix, OVector,
+    RealField, Vector, U1,
 };
 use num_traits::{One, Zero};
 use thiserror::Error;
 
 use crate::{
-    core::{Domain, Error, Problem, Solver, System, VectorDomainExt},
+    core::{Domain, Problem, ProblemError, Solver, System, VectorDomainExt},
     derivatives::{Jacobian, JacobianError, EPSILON_SQRT},
 };
 
@@ -174,7 +175,7 @@ where
 pub enum TrustRegionError {
     /// Error that occurred when evaluating the system.
     #[error("{0}")]
-    Problem(#[from] Error),
+    Problem(#[from] ProblemError),
     /// Error that occurred when computing the Jacobian matrix.
     #[error("{0}")]
     Jacobian(#[from] JacobianError),
@@ -206,7 +207,7 @@ where
         fx: &mut Vector<F::Scalar, F::Dim, Sfx>,
     ) -> Result<(), Self::Error>
     where
-        Sx: StorageMut<F::Scalar, F::Dim>,
+        Sx: StorageMut<F::Scalar, F::Dim> + IsContiguous,
         Sfx: StorageMut<F::Scalar, F::Dim>,
     {
         let TrustRegionOptions {
@@ -238,6 +239,7 @@ where
             ..
         } = self;
 
+        #[allow(clippy::needless_late_init)]
         let scaled_newton: &mut OVector<F::Scalar, F::Dim>;
         let scale_inv2: &mut OVector<F::Scalar, F::Dim>;
         let cauchy_scaled: &mut OVector<F::Scalar, F::Dim>;
@@ -347,7 +349,7 @@ where
                 // Compute D^(-2) (use p for storage).
                 scale_inv2 = p;
                 scale_inv2.copy_from(scale);
-                scale_inv2.apply(|s| F::Scalar::one() / (s * s));
+                scale_inv2.apply(|s| *s = F::Scalar::one() / (*s * *s));
 
                 // Compute g = -D^(-2) grad F, the steepest descent direction in
                 // scaled space (use cauchy for storage).
